import { AsyncStorage } from 'react-native';

const PREFIX = '@cookie:';

const addPrefix = (key) => `${PREFIX}${key}`;

const removePrefix = (key = '') => key.replace(PREFIX, '');

const hasPrefix = (key = '') => (new RegExp(`^${PREFIX}`)).test(key);

const stringify = val => typeof val === 'string'? val: JSON.stringify(val);



const isObject = (val) => val !== null && typeof val === 'object' && val instanceof Object;

/* setters */
const set = (key, val) => {
  const obj = isObject(key)? key : {[key]: val};
  const pairs = Object.keys(obj).map(key => [addPrefix(key), stringify(obj[key])]);

  return AsyncStorage.multiSet(pairs);
};

/* getters */
const get = key => AsyncStorage.getItem(addPrefix(key));

const getAll = () => AsyncStorage.getAllKeys()
  .then(keys => keys.filter(hasPrefix))
  .then(keys => AsyncStorage.multiGet(keys))
  .then(pairs => {
    const cookies = {};
    pairs.forEach(([key, val]) => {
      cookies[removePrefix(key)] = val;
    });
    return cookies;
  });

/* removers */
const remove = key => AsyncStorage.removeItem(addPrefix(key));

const clearAll = () => AsyncStorage.clear();

/* Used only for tests, it's private, don't use it */
const _mock = obj => {
  const pairs = Object.keys(obj).map(key => [addPrefix(key), stringify(obj[key])]);
  return AsyncStorage.multiSet(pairs);
};

const _platform = 'react native';

var reactNative$1 = { set, get, getAll, remove, clearAll, _mock, _platform };

export default reactNative$1;
